// DlgCalibration.cpp : implementation file
//
#include "stdafx.h"
#include "AnalogCtrl.h"
#include "DlgCalibration.h"
#include "IniData.h"


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CDlgCalibration dialog


CDlgCalibration::CDlgCalibration(CWnd* pParent /*=NULL*/)
	: CDialog(CDlgCalibration::IDD, pParent)
{
	//{{AFX_DATA_INIT(CDlgCalibration)
	m_nAdcMax = 0;
	m_nAdcMin = 0;
	m_nCurAdc = 0;
	m_fCurReal = 0.0f;
	m_fRealMax = 0.0f;
	m_fRealMin = 0.0f;
	m_fFilterGain = 1.0f;
	m_nLowWarning = 0;
	m_nLowLimit = 0;
	m_nUpLimit = 0;
	m_nUpWarning = 0;
	//}}AFX_DATA_INIT
	m_sEntry = "";
	m_aiInfo.nScale = scaleCOMMON; 
	m_pIniData = new CIniData;
	
	m_aiInfo.nCurAdc = 0;
	m_aiInfo.fCurReal = 0.0f;
	m_bPermitAccess = TRUE;

	m_pParentWnd = NULL;
}
void CDlgCalibration::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CDlgCalibration)
	DDX_Control(pDX, IDC_LIMIT_SET, m_macLimitSet);
	DDX_Text(pDX, IDC_ADC_MAX, m_nAdcMax);
	DDX_Text(pDX, IDC_ADC_MIN, m_nAdcMin);
	DDX_Text(pDX, IDC_CUR_ADC, m_nCurAdc);
	DDX_Text(pDX, IDC_CUR_REAL, m_fCurReal);
	DDX_Text(pDX, IDC_REAL_MAX, m_fRealMax);
	DDX_Text(pDX, IDC_REAL_MIN, m_fRealMin);
	DDX_Text(pDX, IDC_ADC_FILTER_GAIN, m_fFilterGain);
	DDX_Control(pDX, IDC_CALIBRATION, m_macCalibration);	
	DDX_Control(pDX, IDC_DEFAULT, m_macDefault);
	DDX_Control(pDX, IDC_RADIO_SCALE1, m_macCommon);
	DDX_Control(pDX, IDC_RADIO_SCALE2, m_macLog);
	DDX_Control(pDX, IDC_RADIO_SCALE3, m_macLog10);
	DDX_Text(pDX, IDC_LO_WARN, m_nLowWarning);
	DDX_Text(pDX, IDC_LO_LIMT, m_nLowLimit);
	DDX_Text(pDX, IDC_UP_LIMIT, m_nUpLimit);
	DDX_Text(pDX, IDC_UP_WARN, m_nUpWarning);
	//}}AFX_DATA_MAP
}
BEGIN_MESSAGE_MAP(CDlgCalibration, CDialog)
	//{{AFX_MSG_MAP(CDlgCalibration)
	ON_BN_CLICKED(IDC_CALIBRATION, OnCalibration)
	ON_BN_CLICKED(IDC_DEFAULT, OnDefault)
	ON_BN_CLICKED(IDC_LIMIT_SET, OnLimitSet)
	ON_WM_TIMER()
	ON_WM_DESTROY()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CDlgCalibration message handlers
BOOL CDlgCalibration::OnInitDialog() 
{
	CDialog::OnInitDialog();
	CAnalogCtrlApp* pApp = ( CAnalogCtrlApp* ) AfxGetApp();

	VERIFY( m_Ok.AutoLoad( IDOK, this ) );
	VERIFY( m_Cancel.AutoLoad( IDCANCEL, this ) );

	GetCalPara( m_nID);
	GetLimitAlarmSet( m_nID);
	
	CString sTitle;
	sTitle.Format("AI Calibration : %s", m_sTilteName );
	MAC_COLOR_SET color_set;
	m_macCalibration.GetColorSetting( &color_set );
	color_set.crFace = LIGHT_GREEN_COLOR;
	color_set.crLiteShadow = MAGENTA_COLOR;
	m_macCalibration.SetColorSetting( color_set );
	m_macCalibration.SetBold();

	m_macDefault.GetColorSetting( &color_set );
	color_set.crFace = LIGHT_GREEN_COLOR;
	color_set.crLiteShadow = MAGENTA_COLOR;
	m_macDefault.SetColorSetting( color_set );
	m_macDefault.SetBold();

	m_macLimitSet.GetColorSetting( &color_set );
	color_set.crFace = LIGHT_RED_COLOR;
	color_set.crLiteShadow = MAGENTA_COLOR;
	m_macLimitSet.SetColorSetting( color_set );
	m_macLimitSet.SetBold();

	// Enable the control
	if( !m_bPermitAccess ) 
	{
		GetDlgItem( IDC_CALIBRATION )->EnableWindow( FALSE );
		GetDlgItem( IDC_DEFAULT )->EnableWindow( FALSE );
		GetDlgItem( IDOK )->EnableWindow( FALSE );
		GetDlgItem( IDC_LIMIT_SET )->EnableWindow( FALSE );

		GetDlgItem( IDC_ADC_MAX )->EnableWindow( FALSE );
		GetDlgItem( IDC_ADC_MIN )->EnableWindow( FALSE );
		GetDlgItem( IDC_REAL_MAX )->EnableWindow( FALSE );
		GetDlgItem( IDC_REAL_MIN )->EnableWindow( FALSE );
		GetDlgItem( IDC_RADIO_SCALE1 )->EnableWindow( FALSE );
		GetDlgItem( IDC_RADIO_SCALE2 )->EnableWindow( FALSE );
		GetDlgItem( IDC_RADIO_SCALE3 )->EnableWindow( FALSE );
		GetDlgItem( IDC_ADC_FILTER_GAIN )->EnableWindow( FALSE );


		GetDlgItem( IDC_LO_WARN )->EnableWindow( FALSE );
		GetDlgItem( IDC_LO_LIMT )->EnableWindow( FALSE );
		GetDlgItem( IDC_UP_LIMIT )->EnableWindow( FALSE );
		GetDlgItem( IDC_UP_WARN )->EnableWindow( FALSE );
	}
	
	int nScale;
	GetAiCalScale( m_nID, nScale );
	if( nScale == scaleCOMMON )
	{
		m_macCommon.SetCheck( 1 );
		m_macLog.SetCheck( 0 );
		m_macLog10.SetCheck( 0 );
	}
	else if( nScale == scaleLOG )
	{
		m_macCommon.SetCheck( 0 );
		m_macLog.SetCheck( 1 );
		m_macLog10.SetCheck( 0 );
	}
	else if( nScale == scaleLOG10 )
	{
		m_macCommon.SetCheck( 0 );
		m_macLog.SetCheck( 0 );
		m_macLog10.SetCheck( 1 );
	}

	SetWindowText( sTitle );

	m_pDlg = new CDlgSelSensor();
	{
		CRect r;
		m_pDlg->Create( "CDlgSelSensor", "SELECTION", WS_VISIBLE, r, this, IDD_DIALOG_SEL_SENSOR, NULL );
	}

	SetTimer( 1, 500, NULL);

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CDlgCalibration::SetCalPara(int nID, float fRealMax, float fRealMin, int nAdcMax, int nAdcMin )
{
	m_pIniData->Open("AiControl","AiControl" );

	m_aiInfo.fRealMax = fRealMax;
	m_aiInfo.fRealMin = fRealMin;
	m_aiInfo.nAdcMax = nAdcMax;
	m_aiInfo.nAdcMin = nAdcMin;
	m_aiInfo.m_fFilterGain = m_fFilterGain;

	CString sEntry;
	CString sVal;
	CString sGetID;


	sGetID.Format("AI_REAL_MAX%d",nID);
	sVal.Format( "%.4f", m_fRealMax );
	m_pIniData->SetStringValue("REAL_MAX",sGetID ,sVal, TRUE );
	
	sGetID.Format("AI_REAL_MIN%d",nID);
	sVal.Format( "%.4f", m_fRealMin );
	m_pIniData->SetStringValue("REAL_MIN",sGetID ,sVal, TRUE );

	sGetID.Format("AI_ADC_MAX%d",nID);
	sVal.Format( "%d", m_nAdcMax );
	m_pIniData->SetStringValue("ADC_MAX",sGetID ,sVal, TRUE );

	sGetID.Format("AI_ADC_MIN%d",nID);
	sVal.Format( "%d", m_nAdcMin );
	m_pIniData->SetStringValue("ADC_MIN",sGetID ,sVal, TRUE );

}

void CDlgCalibration::OnCalibration() 
{
	// TODO: Add your control notification handler code here
	UpdateData( TRUE );
	m_macCalibration.SetCheck( 0 );
	SetCalPara( m_nID , m_fRealMax,m_fRealMin,m_nAdcMax,m_nAdcMin );
	SetFilterGain( m_nID, m_fFilterGain );
	if( m_macCommon.GetCheck() ) 	SetAiCalScale( m_nID, scaleCOMMON );
	else if( m_macLog.GetCheck() ) 	SetAiCalScale( m_nID, scaleLOG );
	else if( m_macLog10.GetCheck() ) SetAiCalScale( m_nID, scaleLOG10 );
	UpdateData( FALSE );
	
}
void CDlgCalibration::GetCalPara(int nID)
{
	CString sVal;
	CString sGetID;

	m_pIniData->Open("AiControl","AiControl" );

	sGetID.Format("AI_REAL_MAX%d",nID);
	sVal = m_pIniData->GetStringValue("REAL_MAX",sGetID ,"0" );
	m_fRealMax = (float)atof( sVal );

	sGetID.Format("AI_REAL_MIN%d",nID);
	sVal = m_pIniData->GetStringValue("REAL_MIN",sGetID ,"0" );
	m_fRealMin = (float)atof( sVal );

	sGetID.Format("AI_ADC_MAX%d",nID);
	sVal = m_pIniData->GetStringValue("ADC_MAX",sGetID ,"0" );
	m_nAdcMax = (int)atoi( sVal );

	sGetID.Format("AI_ADC_MIN%d",nID);
	sVal = m_pIniData->GetStringValue("ADC_MIN",sGetID ,"0" );
	m_nAdcMin = (int)atoi( sVal );

	sGetID.Format("AI_FILTER_GAIN%d",nID);
	sVal = m_pIniData->GetStringValue("FILTER_GAIN",sGetID ,"0" );
	m_fFilterGain = (float)atof( sVal );

	m_aiInfo.fRealMax = m_fRealMax;
	m_aiInfo.fRealMin = m_fRealMin;
	m_aiInfo.nAdcMax = m_nAdcMax;
	m_aiInfo.nAdcMin = m_nAdcMin;
	m_aiInfo.m_fFilterGain = m_fFilterGain;
	
	UpdateData( FALSE);
}

void CDlgCalibration::SetFilterGain(int nID, float f)
{

	CString sGetID, sVal;
	if( f < (float)0.1 ) f = (float)0.1;
	else if( f > 1. ) f = 1.;

	m_aiInfo.m_fFilterGain = f;
	sGetID.Format("AI_FILTER_GAIN%d",nID);
	sVal.Format( "%.1f", m_aiInfo.m_fFilterGain );
	m_pIniData->SetStringValue("FILTER_GAIN",sGetID ,sVal, TRUE );
}

void CDlgCalibration::GetCalInitPara(int nID)
{
	CString sEntry;
	CString sVal;
	CString sGetID;

	m_pIniData->Open("AiControl","AiControl" );

	sGetID.Format("AI_REAL_MAX%d",nID);
	sVal = m_pIniData->GetStringValue("REAL_MAX",sGetID ,"0" );
	m_fRealMax = (float)atof( sVal );

	sGetID.Format("AI_REAL_MIN%d",nID);
	sVal = m_pIniData->GetStringValue("REAL_MIN",sGetID ,"0" );
	m_fRealMin = (float)atof( sVal );

	sGetID.Format("AI_ADC_MAX%d",nID);
	sVal = m_pIniData->GetStringValue("ADC_MAX",sGetID ,"0" );
	m_nAdcMax = (int)atoi( sVal );

	sGetID.Format("AI_ADC_MIN%d",nID);
	sVal = m_pIniData->GetStringValue("ADC_MIN",sGetID ,"0" );
	m_nAdcMin = (int)atoi( sVal );

	sGetID.Format("AI_FILTER_GAIN%d",nID);
	sVal = m_pIniData->GetStringValue("FILTER_GAIN",sGetID ,"0" );
	m_fFilterGain = (float)atof( sVal );

	sGetID.Format("AI_LO_LIMIT%d",nID);
	sVal = m_pIniData->GetStringValue("LO_LIMIT",sGetID ,"0" );
	m_nLowLimit = (int)atoi( sVal );

	sGetID.Format("AI_LO_WARN%d",nID);
	sVal = m_pIniData->GetStringValue("LO_WARN",sGetID ,"0" );
	m_nLowWarning = (int)atoi( sVal );

	sGetID.Format("AI_UP_WARN%d",nID);
	sVal = m_pIniData->GetStringValue("UP_WARN",sGetID ,"0" );
	m_nUpWarning = (int)atoi( sVal );

	sGetID.Format("AI_UP_LIMIT%d",nID);
	sVal = m_pIniData->GetStringValue("UP_LIMIT",sGetID ,"0" );
	m_nUpLimit = (int)atoi( sVal );

	sGetID.Format("SCALE%d",nID);
	sVal = m_pIniData->GetStringValue("CALIBRATION_SCALE",sGetID ,"0" );
	m_nScale = (int)atoi( sVal );

	m_aiInfo.nScale = m_nScale;
	m_aiInfo.fRealMax = m_fRealMax;
	m_aiInfo.fRealMin = m_fRealMin;
	m_aiInfo.nAdcMax = m_nAdcMax;
	m_aiInfo.nAdcMin = m_nAdcMin;
	m_aiInfo.m_fFilterGain = m_fFilterGain;

	m_aiInfo.nLoLimit = m_nLowLimit;
	m_aiInfo.nLoWarning = m_nLowWarning;
	m_aiInfo.nUpWarning = m_nUpWarning;
	m_aiInfo.nUpLimit = m_nUpLimit;
}

void CDlgCalibration::OnDefault() 
{
	// TODO: Add your control notification handler code here
	m_macDefault.SetCheck( 0 );

	m_pDlg->ShowWindow( SW_SHOW );

//	m_Dlg.DoModal();
//	DefaultSetting( m_pDlg.m_nNo );
//	UpdateData( FALSE );
}

void CDlgCalibration::DefaultSetting(int nSensorType )
{
	m_aiInfo.fRealMax = m_fRealMax = m_pDlg->m_aiPreSet[nSensorType].fRealMax;
	m_aiInfo.fRealMin = m_fRealMin = m_pDlg->m_aiPreSet[nSensorType].fRealMin;
	m_aiInfo.nAdcMax = m_nAdcMax = m_pDlg->m_aiPreSet[nSensorType].nAdcMax;
	m_aiInfo.nAdcMin = m_nAdcMin = m_pDlg->m_aiPreSet[nSensorType].nAdcMin;
	UpdateData( FALSE );
}

void CDlgCalibration::GetAiCalScale(int nID, int &nScale)
{
	m_pIniData->Open("AiControl","AiControl" );
	CString sGetID;
	CString sVal;

	sGetID.Format("SCALE%d",nID);
	sVal = m_pIniData->GetStringValue("CALIBRATION_SCALE",sGetID ,"0" );
	nScale = atoi( sVal );
}

void CDlgCalibration::SetAiCalScale(int nID, int nScale)
{
	m_pIniData->Open("AiControl","AiControl" );
	CString sGetID;
	CString sVal;

	m_aiInfo.nScale = nScale;
	sGetID.Format("SCALE%d",nID);
	sVal.Format( "%d", nScale );
	m_pIniData->SetStringValue("CALIBRATION_SCALE",sGetID ,sVal, TRUE );
}

void CDlgCalibration::OnLimitSet() 
{
	// TODO: Add your control notification handler code here
	UpdateData( TRUE );
	m_macLimitSet.SetCheck( 0 );
	SetLimitAlarmSet( m_nID,m_nLowLimit, m_nLowWarning, m_nUpWarning, m_nUpLimit );
}

void CDlgCalibration::GetLimitAlarmSet(int nID)
{
	CString sEntry;
	CString sVal;
	CString sGetID;
	m_pIniData->Open("AiControl","AiControl" );

	sGetID.Format("AI_LO_LIMIT%d",nID);
	sVal = m_pIniData->GetStringValue("LO_LIMIT",sGetID ,"0" );
	m_nLowLimit = atoi( sVal );

	sGetID.Format("AI_LO_WARN%d",nID);
	sVal = m_pIniData->GetStringValue("LO_WARN",sGetID ,"0" );
	m_nLowWarning = atoi( sVal );

	sGetID.Format("AI_UP_WARN%d",nID);
	sVal = m_pIniData->GetStringValue("UP_WARN",sGetID ,"0" );
	m_nUpWarning = atoi( sVal );

	sGetID.Format("AI_UP_LIMIT%d",nID);
	sVal = m_pIniData->GetStringValue("UP_LIMIT",sGetID ,"0" );
	m_nUpLimit = atoi( sVal );

	m_aiInfo.nLoLimit = m_nLowLimit;
	m_aiInfo.nLoWarning = m_nLowWarning;
	m_aiInfo.nUpWarning = m_nUpWarning;
	m_aiInfo.nUpLimit = m_nUpLimit;
	UpdateData( FALSE );
}

void CDlgCalibration::SetLimitAlarmSet(int nID, int nLoLimt, int nLoWarning, int nUpWarning, int nUpLimt )
{
	m_pIniData->Open("AiControl","AiControl" );
	
	m_aiInfo.nLoLimit = nLoLimt;
	m_aiInfo.nLoWarning = nLoWarning;
	m_aiInfo.nUpWarning = nUpWarning;
	m_aiInfo.nUpLimit = nUpLimt;

	CString sEntry;
	CString sVal;
	CString sGetID;

	sGetID.Format("AI_LO_LIMIT%d",nID);
	sVal.Format( "%d", m_nLowLimit );
	m_pIniData->SetStringValue("LO_LIMIT",sGetID ,sVal, TRUE );
	
	sGetID.Format("AI_LO_WARN%d",nID);
	sVal.Format( "%d", m_nLowWarning );
	m_pIniData->SetStringValue("LO_WARN",sGetID ,sVal, TRUE );

	sGetID.Format("AI_UP_WARN%d",nID);
	sVal.Format( "%d", m_nUpWarning );
	m_pIniData->SetStringValue("UP_WARN",sGetID ,sVal, TRUE );

	sGetID.Format("AI_UP_LIMIT%d",nID);
	sVal.Format( "%d", m_nUpLimit );
	m_pIniData->SetStringValue("UP_LIMIT",sGetID ,sVal, TRUE );
		
	m_aiInfo.nLoLimit = m_nLowLimit;
	m_aiInfo.nLoWarning = m_nLowWarning;
	m_aiInfo.nUpWarning = m_nUpWarning;
	m_aiInfo.nUpLimit = m_nUpLimit;
}

void CDlgCalibration::OnTimer(UINT nIDEvent) 
{
	// TODO: Add your message handler code here and/or call default
	 m_nCurAdc = m_aiInfo.nCurAdc;
	 m_fCurReal = m_aiInfo.fCurReal;
	//if( m_nCurAdc < 1 || m_fCurReal < 1 ) return;
	CString strCurReal;
	strCurReal.Format( "%.1f", m_fCurReal );
	SetDlgItemText( IDC_CUR_REAL, strCurReal );
	SetDlgItemInt( IDC_CUR_ADC, m_nCurAdc );
	CDialog::OnTimer(nIDEvent);
}

void CDlgCalibration::OnDestroy() 
{
	CDialog::OnDestroy();
	
	// TODO: Add your message handler code here
	KillTimer( 1 );
	if( m_pDlg ) delete m_pDlg;
	m_pDlg = NULL;
}

void CDlgCalibration::OnOK() 
{
	// TODO: Add extra validation here
	m_pParentWnd->PostMessage( WM_CALIBRATION_END, 0, 0 );
	CDialog::OnOK();
}

void CDlgCalibration::OnCancel() 
{
	// TODO: Add extra cleanup here
	m_pParentWnd->PostMessage( WM_CALIBRATION_END, 0, 0 );
	CDialog::OnCancel();
}

BOOL CDlgCalibration::Create(LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext) 
{
	// TODO: Add your specialized code here and/or call the base class
	m_pParentWnd = pParentWnd;
	return CDialog::Create(IDD, pParentWnd);
}
